Learn R Programming

mglasso (version 0.1.2)

beta_to_vector: Transform a matrix of regression coefficients to vector removing the diagonal

Description

Transform a matrix of regression coefficients to vector removing the diagonal

Usage

beta_to_vector(beta_mat)

Value

A numeric vector of all regression coefficients.

Arguments

beta_mat

matrix of regressions vectors