pylearn-parsimony contains the solver CONESTA used for the mglasso problem and is available on github at https://github.com/neurospin/pylearn-parsimony It is advised to use a python version ">=3.7,<3.10". Indeed, the latest version of scipy under which mglasso was developped is scipy 1.7.1 which is based on python ">=3.7,<3.10". In turn, this version of scipy can only be associated with a version of numpy ">=1.16.5,<1.23.0"
install_pylearn_parsimony(
method = c("auto", "virtualenv", "conda"),
conda = "auto",
extra_pack = c("scipy == 1.7.1", "scikit-learn", "numpy == 1.22.4", "six",
"matplotlib"),
python_version = "3.8",
restart_session = TRUE,
envname = NULL,
...
)No return value.
Installation method. By default, "auto" automatically finds a method that will work in the local environment. Change the default to force a specific installation method. Note that the "virtualenv" method is not available on Windows.
The path to a conda executable. Use "auto" to allow
reticulate to automatically find an appropriate conda binary.
See Finding Conda and conda_binary() for more details.
Character vector. Extra-packages to be installed.
The requested Python version. Ignored when attempting to install with a Python virtual environment.
Restart R session after installing (note this will only occur within RStudio)
The name, or full path, of the environment in which Python
packages are to be installed. When NULL (the default), the active
environment as set by the RETICULATE_PYTHON_ENV variable will be used;
if that is unset, then the r-reticulate environment will be used.
additionnal arguments passed to reticulate::py_install()